==> ZendFramework-1.11.11.tbz: share/examples/ZendFramework/tests/Zend/Barcode/Object/_files/Ean8_123456_border_instructions.php <==
<?php
return
array (
  0 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 0,
        1 => 0,
      ),
      1 => 
      array (
        0 => 0,
        1 => 65,
      ),
      2 => 
      array (
        0 => 88,
        1 => 65,
      ),
      3 => 
      array (
        0 => 88,
        1 => 0,
      ),
    ),
    'color' => 16777215,
    'filled' => true,
  ),
  1 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 11,
        1 => 1,
      ),
      1 => 
      array (
        0 => 11,
        1 => 56,
      ),
      2 => 
      array (
        0 => 11,
        1 => 56,
      ),
      3 => 
      array (
        0 => 11,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  2 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 13,
        1 => 1,
      ),
      1 => 
      array (
        0 => 13,
        1 => 56,
      ),
      2 => 
      array (
        0 => 13,
        1 => 56,
      ),
      3 => 
      array (
        0 => 13,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  3 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 17,
        1 => 1,
      ),
      1 => 
      array (
        0 => 17,
        1 => 51,
      ),
      2 => 
      array (
        0 => 17,
        1 => 51,
      ),
      3 => 
      array (
        0 => 17,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  4 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 18,
        1 => 1,
      ),
      1 => 
      array (
        0 => 18,
        1 => 51,
      ),
      2 => 
      array (
        0 => 18,
        1 => 51,
      ),
      3 => 
      array (
        0 => 18,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  5 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 20,
        1 => 1,
      ),
      1 => 
      array (
        0 => 20,
        1 => 51,
      ),
      2 => 
      array (
        0 => 20,
        1 => 51,
      ),
      3 => 
      array (
        0 => 20,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  6 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 23,
        1 => 1,
      ),
      1 => 
      array (
        0 => 23,
        1 => 51,
      ),
      2 => 
      array (
        0 => 23,
        1 => 51,
      ),
      3 => 
      array (
        0 => 23,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  7 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 24,
        1 => 1,
      ),
      1 => 
      array (
        0 => 24,
        1 => 51,
      ),
      2 => 
      array (
        0 => 24,
        1 => 51,
      ),
      3 => 
      array (
        0 => 24,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  8 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 27,
        1 => 1,
      ),
      1 => 
      array (
        0 => 27,
        1 => 51,
      ),
      2 => 
      array (
        0 => 27,
        1 => 51,
      ),
      3 => 
      array (
        0 => 27,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  9 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 30,
        1 => 1,
      ),
      1 => 
      array (
        0 => 30,
        1 => 51,
      ),
      2 => 
      array (
        0 => 30,
        1 => 51,
      ),
      3 => 
      array (
        0 => 30,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  10 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 33,
        1 => 1,
      ),
      1 => 
      array (
        0 => 33,
        1 => 51,
      ),
      2 => 
      array (
        0 => 33,
        1 => 51,
      ),
      3 => 
      array (
        0 => 33,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  11 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 34,
        1 => 1,
      ),
      1 => 
      array (
        0 => 34,
        1 => 51,
      ),
      2 => 
      array (
        0 => 34,
        1 => 51,
      ),
      3 => 
      array (
        0 => 34,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  12 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 36,
        1 => 1,
      ),
      1 => 
      array (
        0 => 36,
        1 => 51,
      ),
      2 => 
      array (
        0 => 36,
        1 => 51,
      ),
      3 => 
      array (
        0 => 36,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  13 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 37,
        1 => 1,
      ),
      1 => 
      array (
        0 => 37,
        1 => 51,
      ),
      2 => 
      array (
        0 => 37,
        1 => 51,
      ),
      3 => 
      array (
        0 => 37,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  14 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 38,
        1 => 1,
      ),
      1 => 
      array (
        0 => 38,
        1 => 51,
      ),
      2 => 
      array (
        0 => 38,
        1 => 51,
      ),
      3 => 
      array (
        0 => 38,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  15 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 39,
        1 => 1,
      ),
      1 => 
      array (
        0 => 39,
        1 => 51,
      ),
      2 => 
      array (
        0 => 39,
        1 => 51,
      ),
      3 => 
      array (
        0 => 39,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  16 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 41,
        1 => 1,
      ),
      1 => 
      array (
        0 => 41,
        1 => 51,
      ),
      2 => 
      array (
        0 => 41,
        1 => 51,
      ),
      3 => 
      array (
        0 => 41,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  17 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 43,
        1 => 1,
      ),
      1 => 
      array (
        0 => 43,
        1 => 56,
      ),
      2 => 
      array (
        0 => 43,
        1 => 56,
      ),
      3 => 
      array (
        0 => 43,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  18 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 45,
        1 => 1,
      ),
      1 => 
      array (
        0 => 45,
        1 => 56,
      ),
      2 => 
      array (
        0 => 45,
        1 => 56,
      ),
      3 => 
      array (
        0 => 45,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  19 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 47,
        1 => 1,
      ),
      1 => 
      array (
        0 => 47,
        1 => 51,
      ),
      2 => 
      array (
        0 => 47,
        1 => 51,
      ),
      3 => 
      array (
        0 => 47,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  20 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 49,
        1 => 1,
      ),
      1 => 
      array (
        0 => 49,
        1 => 51,
      ),
      2 => 
      array (
        0 => 49,
        1 => 51,
      ),
      3 => 
      array (
        0 => 49,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  21 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 50,
        1 => 1,
      ),
      1 => 
      array (
        0 => 50,
        1 => 51,
      ),
      2 => 
      array (
        0 => 50,
        1 => 51,
      ),
      3 => 
      array (
        0 => 50,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  22 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 51,
        1 => 1,
      ),
      1 => 
      array (
        0 => 51,
        1 => 51,
      ),
      2 => 
      array (
        0 => 51,
        1 => 51,
      ),
      3 => 
      array (
        0 => 51,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  23 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 54,
        1 => 1,
      ),
      1 => 
      array (
        0 => 54,
        1 => 51,
      ),
      2 => 
      array (
        0 => 54,
        1 => 51,
      ),
      3 => 
      array (
        0 => 54,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  24 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 57,
        1 => 1,
      ),
      1 => 
      array (
        0 => 57,
        1 => 51,
      ),
      2 => 
      array (
        0 => 57,
        1 => 51,
      ),
      3 => 
      array (
        0 => 57,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  25 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 58,
        1 => 1,
      ),
      1 => 
      array (
        0 => 58,
        1 => 51,
      ),
      2 => 
      array (
        0 => 58,
        1 => 51,
      ),
      3 => 
      array (
        0 => 58,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  26 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 59,
        1 => 1,
      ),
      1 => 
      array (
        0 => 59,
        1 => 51,
      ),
      2 => 
      array (
        0 => 59,
        1 => 51,
      ),
      3 => 
      array (
        0 => 59,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  27 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 61,
        1 => 1,
      ),
      1 => 
      array (
        0 => 61,
        1 => 51,
      ),
      2 => 
      array (
        0 => 61,
        1 => 51,
      ),
      3 => 
      array (
        0 => 61,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  28 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 63,
        1 => 1,
      ),
      1 => 
      array (
        0 => 63,
        1 => 51,
      ),
      2 => 
      array (
        0 => 63,
        1 => 51,
      ),
      3 => 
      array (
        0 => 63,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  29 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 68,
        1 => 1,
      ),
      1 => 
      array (
        0 => 68,
        1 => 51,
      ),
      2 => 
      array (
        0 => 68,
        1 => 51,
      ),
      3 => 
      array (
        0 => 68,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  30 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 71,
        1 => 1,
      ),
      1 => 
      array (
        0 => 71,
        1 => 51,
      ),
      2 => 
      array (
        0 => 71,
        1 => 51,
      ),
      3 => 
      array (
        0 => 71,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  31 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 72,
        1 => 1,
      ),
      1 => 
      array (
        0 => 72,
        1 => 51,
      ),
      2 => 
      array (
        0 => 72,
        1 => 51,
      ),
      3 => 
      array (
        0 => 72,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  32 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 73,
        1 => 1,
      ),
      1 => 
      array (
        0 => 73,
        1 => 51,
      ),
      2 => 
      array (
        0 => 73,
        1 => 51,
      ),
      3 => 
      array (
        0 => 73,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  33 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 75,
        1 => 1,
      ),
      1 => 
      array (
        0 => 75,
        1 => 56,
      ),
      2 => 
      array (
        0 => 75,
        1 => 56,
      ),
      3 => 
      array (
        0 => 75,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  34 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 77,
        1 => 1,
      ),
      1 => 
      array (
        0 => 77,
        1 => 56,
      ),
      2 => 
      array (
        0 => 77,
        1 => 56,
      ),
      3 => 
      array (
        0 => 77,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  35 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 0,
        1 => 0,
      ),
      1 => 
      array (
        0 => 88,
        1 => 0,
      ),
      2 => 
      array (
        0 => 88,
        1 => 65,
      ),
      3 => 
      array (
        0 => 0,
        1 => 65,
      ),
      4 => 
      array (
        0 => 0,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => false,
  ),
  36 => 
  array (
    'type' => 'text',
    'text' => '0',
    'size' => 10,
    'position' => 
    array (
      0 => 13,
      1 => 63,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
  37 => 
  array (
    'type' => 'text',
    'text' => '1',
    'size' => 10,
    'position' => 
    array (
      0 => 20,
      1 => 63,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
  38 => 
  array (
    'type' => 'text',
    'text' => '2',
    'size' => 10,
    'position' => 
    array (
      0 => 27,
      1 => 63,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
  39 => 
  array (
    'type' => 'text',
    'text' => '3',
    'size' => 10,
    'position' => 
    array (
      0 => 34,
      1 => 63,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
  40 => 
  array (
    'type' => 'text',
    'text' => '4',
    'size' => 10,
    'position' => 
    array (
      0 => 45,
      1 => 63,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
  41 => 
  array (
    'type' => 'text',
    'text' => '5',
    'size' => 10,
    'position' => 
    array (
      0 => 52,
      1 => 63,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
  42 => 
  array (
    'type' => 'text',
    'text' => '6',
    'size' => 10,
    'position' => 
    array (
      0 => 59,
      1 => 63,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
  43 => 
  array (
    'type' => 'text',
    'text' => '5',
    'size' => 10,
    'position' => 
    array (
      0 => 66,
      1 => 63,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'left',
    'orientation' => 0,
  ),
);

==> ZendFramework-1.12.0_1.tbz: share/examples/ZendFramework/tests/Zend/Barcode/Object/_files/Ean5_45678_border_instructions.php <==
<?php
return
array (
  0 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 0,
        1 => 0,
      ),
      1 => 
      array (
        0 => 0,
        1 => 65,
      ),
      2 => 
      array (
        0 => 69,
        1 => 65,
      ),
      3 => 
      array (
        0 => 69,
        1 => 0,
      ),
    ),
    'color' => 16777215,
    'filled' => true,
  ),
  1 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 12,
        1 => 1,
      ),
      1 => 
      array (
        0 => 12,
        1 => 51,
      ),
      2 => 
      array (
        0 => 12,
        1 => 51,
      ),
      3 => 
      array (
        0 => 12,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  2 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 14,
        1 => 1,
      ),
      1 => 
      array (
        0 => 14,
        1 => 51,
      ),
      2 => 
      array (
        0 => 14,
        1 => 51,
      ),
      3 => 
      array (
        0 => 14,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  3 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 15,
        1 => 1,
      ),
      1 => 
      array (
        0 => 15,
        1 => 51,
      ),
      2 => 
      array (
        0 => 15,
        1 => 51,
      ),
      3 => 
      array (
        0 => 15,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  4 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 18,
        1 => 1,
      ),
      1 => 
      array (
        0 => 18,
        1 => 51,
      ),
      2 => 
      array (
        0 => 18,
        1 => 51,
      ),
      3 => 
      array (
        0 => 18,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  5 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 19,
        1 => 1,
      ),
      1 => 
      array (
        0 => 19,
        1 => 51,
      ),
      2 => 
      array (
        0 => 19,
        1 => 51,
      ),
      3 => 
      array (
        0 => 19,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  6 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 20,
        1 => 1,
      ),
      1 => 
      array (
        0 => 20,
        1 => 51,
      ),
      2 => 
      array (
        0 => 20,
        1 => 51,
      ),
      3 => 
      array (
        0 => 20,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  7 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 22,
        1 => 1,
      ),
      1 => 
      array (
        0 => 22,
        1 => 51,
      ),
      2 => 
      array (
        0 => 22,
        1 => 51,
      ),
      3 => 
      array (
        0 => 22,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  8 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 24,
        1 => 1,
      ),
      1 => 
      array (
        0 => 24,
        1 => 51,
      ),
      2 => 
      array (
        0 => 24,
        1 => 51,
      ),
      3 => 
      array (
        0 => 24,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  9 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 26,
        1 => 1,
      ),
      1 => 
      array (
        0 => 26,
        1 => 51,
      ),
      2 => 
      array (
        0 => 26,
        1 => 51,
      ),
      3 => 
      array (
        0 => 26,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  10 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 27,
        1 => 1,
      ),
      1 => 
      array (
        0 => 27,
        1 => 51,
      ),
      2 => 
      array (
        0 => 27,
        1 => 51,
      ),
      3 => 
      array (
        0 => 27,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  11 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 31,
        1 => 1,
      ),
      1 => 
      array (
        0 => 31,
        1 => 51,
      ),
      2 => 
      array (
        0 => 31,
        1 => 51,
      ),
      3 => 
      array (
        0 => 31,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  12 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 33,
        1 => 1,
      ),
      1 => 
      array (
        0 => 33,
        1 => 51,
      ),
      2 => 
      array (
        0 => 33,
        1 => 51,
      ),
      3 => 
      array (
        0 => 33,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  13 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 35,
        1 => 1,
      ),
      1 => 
      array (
        0 => 35,
        1 => 51,
      ),
      2 => 
      array (
        0 => 35,
        1 => 51,
      ),
      3 => 
      array (
        0 => 35,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  14 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 37,
        1 => 1,
      ),
      1 => 
      array (
        0 => 37,
        1 => 51,
      ),
      2 => 
      array (
        0 => 37,
        1 => 51,
      ),
      3 => 
      array (
        0 => 37,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  15 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 38,
        1 => 1,
      ),
      1 => 
      array (
        0 => 38,
        1 => 51,
      ),
      2 => 
      array (
        0 => 38,
        1 => 51,
      ),
      3 => 
      array (
        0 => 38,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  16 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 39,
        1 => 1,
      ),
      1 => 
      array (
        0 => 39,
        1 => 51,
      ),
      2 => 
      array (
        0 => 39,
        1 => 51,
      ),
      3 => 
      array (
        0 => 39,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  17 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 40,
        1 => 1,
      ),
      1 => 
      array (
        0 => 40,
        1 => 51,
      ),
      2 => 
      array (
        0 => 40,
        1 => 51,
      ),
      3 => 
      array (
        0 => 40,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  18 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 42,
        1 => 1,
      ),
      1 => 
      array (
        0 => 42,
        1 => 51,
      ),
      2 => 
      array (
        0 => 42,
        1 => 51,
      ),
      3 => 
      array (
        0 => 42,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  19 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 45,
        1 => 1,
      ),
      1 => 
      array (
        0 => 45,
        1 => 51,
      ),
      2 => 
      array (
        0 => 45,
        1 => 51,
      ),
      3 => 
      array (
        0 => 45,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  20 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 49,
        1 => 1,
      ),
      1 => 
      array (
        0 => 49,
        1 => 51,
      ),
      2 => 
      array (
        0 => 49,
        1 => 51,
      ),
      3 => 
      array (
        0 => 49,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  21 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 51,
        1 => 1,
      ),
      1 => 
      array (
        0 => 51,
        1 => 51,
      ),
      2 => 
      array (
        0 => 51,
        1 => 51,
      ),
      3 => 
      array (
        0 => 51,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  22 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 53,
        1 => 1,
      ),
      1 => 
      array (
        0 => 53,
        1 => 51,
      ),
      2 => 
      array (
        0 => 53,
        1 => 51,
      ),
      3 => 
      array (
        0 => 53,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  23 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 54,
        1 => 1,
      ),
      1 => 
      array (
        0 => 54,
        1 => 51,
      ),
      2 => 
      array (
        0 => 54,
        1 => 51,
      ),
      3 => 
      array (
        0 => 54,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  24 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 56,
        1 => 1,
      ),
      1 => 
      array (
        0 => 56,
        1 => 51,
      ),
      2 => 
      array (
        0 => 56,
        1 => 51,
      ),
      3 => 
      array (
        0 => 56,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  25 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 57,
        1 => 1,
      ),
      1 => 
      array (
        0 => 57,
        1 => 51,
      ),
      2 => 
      array (
        0 => 57,
        1 => 51,
      ),
      3 => 
      array (
        0 => 57,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  26 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 58,
        1 => 1,
      ),
      1 => 
      array (
        0 => 58,
        1 => 51,
      ),
      2 => 
      array (
        0 => 58,
        1 => 51,
      ),
      3 => 
      array (
        0 => 58,
        1 => 1,
      ),
    ),
    'color' => 0,
    'filled' => true,
  ),
  27 => 
  array (
    'type' => 'polygon',
    'points' => 
    array (
      0 => 
      array (
        0 => 0,
        1 => 0,
      ),
      1 => 
      array (
        0 => 69,
        1 => 0,
      ),
      2 => 
      array (
        0 => 69,
        1 => 65,
      ),
      3 => 
      array (
        0 => 0,
        1 => 65,
      ),
      4 => 
      array (
        0 => 0,
        1 => 0,
      ),
    ),
    'color' => 0,
    'filled' => false,
  ),
  28 => 
  array (
    'type' => 'text',
    'text' => '45678',
    'size' => 10,
    'position' => 
    array (
      0 => 35,
      1 => 63,
    ),
    'font' => NULL,
    'color' => 0,
    'alignment' => 'center',
    'orientation' => 0,
  ),
);
